@@ -1,7 +1,7 @@
 /*
  * $Header$
  *
- * pgpool: a language independent connection pool server for PostgreSQL 
+ * pgpool: a language independent connection pool server for PostgreSQL
  * written by Tatsuo Ishii
  *
  * Copyright (c) 2003-2016	PgPool Global Development Group
@@ -18,15 +18,17 @@
  * is" without express or implied warranty.
  *
  *
- * libpcp_ext.h - 
+ * libpcp_ext.h -
  *	  This file contains definitions for structures and
  *	  externs for functions used by frontend libpcp applications.
  */
 
 #ifndef LIBPCP_EXT_H
 #define LIBPCP_EXT_H
+
 #include <signal.h>
 #include <stdio.h>
+
 /*
  * startup packet definitions (v2) stolen from PostgreSQL
  */
@@ -54,6 +56,13 @@ typedef enum {
 #define BACKEND_STATUS_CON_UP			"up"
 #define BACKEND_STATUS_CON_DOWN			"down"
 
+/*
+ * Backend status record file
+ */
+typedef struct {
+	BACKEND_STATUS status[MAX_NUM_BACKENDS];
+} BackendStatusRecord;
+
 /*
  * PostgreSQL backend descriptor. Placed on shared memory area.
  */
@@ -65,7 +74,7 @@ typedef struct {
 	double unnormalized_weight; /* descripted parameter */
 	char backend_data_directory[MAX_PATH_LENGTH];
 	unsigned short flag;		/* various flags */
-	unsigned long long int standby_delay;		/* The replication delay against the primary */
+	uint64 standby_delay;		/* The replication delay against the primary */
 } BackendInfo;
 
 typedef struct {
